const products = [
  { id: 1, name: 'Product 1', price: 19.99, description: 'Short description of product 1', longDescription: 'Long description of product 1', image: 'product1.jpg' },
  { id: 2, name: 'Product 2', price: 29.99, description: 'Short description of product 2', longDescription: 'Long description of product 2', image: 'product2.jpg' }
];

let cart = [];

function viewProduct(productId) {
  const product = products.find(p => p.id === productId);
  if (product) {
    document.getElementById('products').classList.add('hidden');
    document.getElementById('product-details').classList.remove('hidden');
    document.querySelector('#product-details .details-content').innerHTML = `
      <img src="${product.image}" alt="${product.name}">
      <h3>${product.name}</h3>
      <p>$${product.price.toFixed(2)}</p>
      <p>${product.longDescription}</p>
      <button class="add-to-cart-button" onclick="addToCart(${product.id})">Add to Cart</button>
      <button class="see-more-button" onclick="showProducts()">See More Products</button>
    `;
  }
}

function showProducts() {
  document.getElementById('product-details').classList.add('hidden');
  document.getElementById('cart').classList.add('hidden');
  document.getElementById('products').classList.remove('hidden');
}

function addToCart(productId) {
  const product = products.find(p => p.id === productId);
  if (product) {
    cart.push({ ...product, quantity: 1 });
    alert(`${product.name} added to cart!`);
    updateCartDisplay();
  }
}

function updateCartDisplay() {
  const cartItems = document.querySelector('.cart-items');
  cartItems.innerHTML = '';
  let total = 0;
  cart.forEach(item => {
    total += item.price * item.quantity;
    cartItems.innerHTML += `
      <div class="cart-item">
        <p>${item.name}</p>
        <p>$${item.price.toFixed(2)}</p>
        <input type="number" value="${item.quantity}" onchange="updateQuantity(${item.id}, this.value)">
      </div>
    `;
  });
  document.querySelector('.cart p').innerText = `Total: $${total.toFixed(2)}`;
}

function updateQuantity(productId, quantity) {
  const item = cart.find(i => i.id === productId);
  if (item) {
    item.quantity = parseInt(quantity);
    updateCartDisplay();
  }
}

function placeOrder() {
  alert('Order placed! Thank you for your purchase.');
  cart = [];
  updateCartDisplay();
}

function cancelOrder() {
  cart = [];
  updateCartDisplay();
  alert('Order canceled.');
}

document.querySelector('.cta-button').addEventListener('click', () => {
  document.getElementById('products').classList.add('hidden');
  document.getElementById('product-details').classList.add('hidden');
  document.getElementById('cart').classList.remove('hidden');
});